function [depths,xs,gl_loc] = extrusion_model_s1(av_spacing,tidal_heights,times,angle,mean_flux,d_comp,xs)

v = av_spacing/1;       % 1 tide per day sets average retreat speed in m/day
    
depths = zeros(size(xs)); % set initial bed to smooth
    
gl_loc = tidal_heights/angle+v*times; % add retreat component to grounding line migration

depths = min(depths, ice_shape(xs-gl_loc(1)));

for i = 2:length(times)-1
      
    h_ice = ice_shape(xs- gl_loc(i)); % find the shape of the ice sheet, shifted by grounding line position

    pushed = find(depths>=h_ice); % locate till that the ice encountered by advancing
    bulldozed = sum(depths(pushed)-h_ice(pushed))+mean_flux; % count that till towards the flux to the grounding line
    depths(pushed) = h_ice(pushed); % the bottom of the ice now sets the till depth in that area
    
    if pushed
    pos = min(pushed)-1;
    else
        pos = 0;
    end
    
    while bulldozed > 0 && pos > 0
        space = h_ice(pos) - depths(pos); % how much space is available to fill with bulldozed material
        depths(pos) = depths(pos) + min([space, bulldozed]); % fill it in
        bulldozed = bulldozed - space; % remove from available volume
        pos = pos - 1; % move further ahead of the grounding line to deposit the rest
    end
    
end

depths = smooth(depths);
xs = xs(400:3400); % crop out spin-up
depths = depths(400:3400);

    % prescribe the shape of the base of the ice, where x = 0 is the grounding line
    
    function h_ice = ice_shape(x)
        h_ice = -angle*x;
        h_ice(x> d_comp/angle) = -d_comp;
        h_ice(x> 2*d_comp/angle) = 0;
    end
    
    
end


